# 2022.8.26, used in ES postag indexing 
oneself = {
"himself": "_oneself", 
"herself":"_oneself", 
"myself":"_oneself", 
"yourself":"_oneself", 
"itself":"_oneself", 
"ourselves":"_oneself", 
"yourselves":"_oneself", 
"themselves":"_oneself", 
"he":"_sb",
"she":"_sb",
"we":"_sb",
"they":"_sb",
"I":"_sb",
"you":"_sb",
"us":"_sb",
"his":"_one's",  # her, her pat, like her 
"one's":"_one's",
}

if __name__	== '__main__':
	print(oneself)